@@ -200,7 +200,7 @@ child_set_text_pos (Child *child)
 	allocation.width = child->width - handle_size - child->decor_width;
 	allocation.height = child->height - (has_focus ? (2 * handle_size) : 0);
 
-	gtk_widget_size_request (child->widget, &child->widget->requisition); /* FIXME: is this needed? */
+	gtk_widget_size_request (child->widget, NULL);
 	gtk_widget_size_allocate (child->widget, &allocation);
 }
 
@@ -428,7 +428,7 @@ edit_appointment (GtkWidget *widget, gpointer data)
 static void
 delete_occurance (GtkWidget *widget, gpointer data)
 {
-	Child *child;
+	Child *child = data;
 	iCalObject *ical;
 	time_t *t;
 	GnomeCalendar *gcal = GNCAL_FULL_DAY (child->widget->parent)->calendar;
@@ -1759,6 +1759,9 @@ recompute_motion (GncalFullDay *fullday, int y)
 	case DRAG_MOVE:
 		has_focus = GTK_WIDGET_HAS_FOCUS (di->child->widget);
 
+		if (has_focus)
+			child_focus_out (di->child->widget, NULL, di->child);
+
 		row = get_row_from_y (fullday, y - di->child_click_y + (has_focus ? HANDLE_SIZE : 0), TRUE);
 
 		if (row > (f_rows - di->child_rows_used))
@@ -1769,6 +1772,11 @@ recompute_motion (GncalFullDay *fullday, int y)
 		break;
 
 	case DRAG_SIZE_TOP:
+		has_focus = GTK_WIDGET_HAS_FOCUS (di->child->widget);
+
+		if (has_focus)
+			child_focus_out (di->child->widget, NULL, di->child);
+
 		row = get_row_from_y (fullday, y + HANDLE_SIZE, TRUE);
 
 		if (row > (di->child_start_row + di->child_rows_used - 1))
@@ -1780,6 +1788,11 @@ recompute_motion (GncalFullDay *fullday, int y)
 		break;
 
 	case DRAG_SIZE_BOTTOM:
+		has_focus = GTK_WIDGET_HAS_FOCUS (di->child->widget);
+
+		if (has_focus)
+			child_focus_out (di->child->widget, NULL, di->child);
+
 		row = get_row_from_y (fullday, y - HANDLE_SIZE, TRUE);
 
 		if (row <= di->child_start_row)
