@@ -77,6 +77,9 @@ static char *load_file;
 /* If set, show events for the specified date and quit */
 static int show_events;
 
+/* If set, show todo items quit */
+static int show_todo;
+
 static void
 init_username (void)
 {
@@ -145,6 +148,7 @@ init_calendar (void)
 	
 	todo_current_sort_type = gnome_config_get_int("/calendar/Todo/sort_type");
 	
+	todo_show_priority = gnome_config_get_bool("/calendar/Todo/show_priority");
 
 	/* Done */
 
@@ -439,6 +443,14 @@ save_default_calendar (GnomeCalendar *gcal)
 	save_calendar_cmd (NULL, gcal);
 }
 
+#if 0
+static void
+make_html_cmd (GtkWidget *widget, GtkWidget *gcal)
+{
+	make_month_html (gcal, "output.html");
+}
+#endif
+
 static GnomeUIInfo gnome_cal_file_menu [] = {
         GNOMEUIINFO_MENU_NEW_ITEM(N_("_New calendar"),
 				  N_("Create a new calendar"),
@@ -452,6 +464,13 @@ static GnomeUIInfo gnome_cal_file_menu [] = {
 
 	GNOMEUIINFO_SEPARATOR,
 
+#if 0
+	GNOMEUIINFO_ITEM(N_("Create HTML for this month"),
+			 N_("Creates an HTML version of this month's appointments"),
+			 make_html_cmd, NULL);
+#endif
+	GNOMEUIINFO_SEPARATOR,
+
 	GNOMEUIINFO_MENU_CLOSE_ITEM(close_cmd, NULL),
 
 	GNOMEUIINFO_MENU_EXIT_ITEM(quit_cmd, NULL),
@@ -471,7 +490,7 @@ static GnomeUIInfo gnome_cal_edit_menu [] = {
 };
 
 static GnomeUIInfo gnome_cal_help_menu [] = {
-	GNOMEUIINFO_HELP ("cal"),
+	GNOMEUIINFO_HELP ("gnomecal"),
 
 	GNOMEUIINFO_MENU_ABOUT_ITEM(about_calendar_cmd, NULL),
 
@@ -519,10 +538,10 @@ setup_menu (GtkWidget *gcal)
 static void
 setup_appbar (GtkWidget *gcal)
 {
-        GnomeAppBar *appbar;
-	
+        GtkWidget *appbar;
+
         appbar = gnome_appbar_new (FALSE, TRUE, GNOME_PREFERENCES_USER);
-	gnome_app_set_statusbar (GNOME_APP (gcal), GTK_WIDGET(appbar));
+	gnome_app_set_statusbar (GNOME_APP (gcal), GTK_WIDGET (appbar));
 }
 
 static gint
@@ -548,9 +567,15 @@ new_calendar (char *full_name, char *calendar_file, char *geometry, char *page,
 	if (gnome_parse_geometry (geometry, &xpos, &ypos, &width, &height)){
 		if (xpos != -1)
 			gtk_widget_set_uposition (toplevel, xpos, ypos);
-		if (width != -1)
-			gtk_widget_set_usize (toplevel, width, height);
+#if 0
+	if (width != -1)
+		gtk_widget_set_usize (toplevel, width, 600);
+#endif
 	}
+#if 0
+ 	gtk_widget_set_usize (toplevel, width, 600); 
+#endif
+
 	setup_appbar (toplevel);
 	setup_menu (toplevel);
 
@@ -596,6 +621,7 @@ enum {
 	USERFILE_KEY = -2,
 	VIEW_KEY     = -3,
 	HIDDEN_KEY   = -4,
+	TODO_KEY     = -5
 };
 
 /* Lists used to startup various GnomeCalendars */
@@ -657,6 +683,34 @@ dump_events (void)
 	exit (0);
 }
 
+static void
+dump_todo (void)
+{
+	Calendar *cal;
+	GList *l;
+	char *s;
+
+	process_dates ();
+	init_calendar ();
+
+	cal = calendar_new (full_name);
+	s = calendar_load (cal, load_file ? load_file : user_calendar_file);
+	if (s){
+		printf ("error: %s\n", s);
+		exit (1);
+	}
+	for (l = cal->todo; l; l = l->next){
+		iCalObject *object = l->data;
+
+		if (object->type != ICAL_TODO)
+			continue;
+
+		printf ("[%s]: %s\n", object->organizer, object->summary);
+	}
+	calendar_destroy (cal);
+	exit (0);
+}
+
 extern time_t get_date ();
 
 static void
@@ -686,7 +740,8 @@ parse_an_arg (poptContext ctx,
 		 */
 		arg = COOKIE_USER_HOME_DIR;
 		/* fall through */
-
+		break;
+		
 	case VIEW_KEY:
 		start_views = g_list_append (start_views, arg);
 		break;
@@ -695,6 +750,10 @@ parse_an_arg (poptContext ctx,
 		start_calendars = g_list_append (start_calendars, arg);
 		break;
 
+	case TODO_KEY:
+		show_todo = 1;
+		break;
+		
 	case 'e':
 		show_events = 1;
 		break;
@@ -711,6 +770,8 @@ static const struct poptOption options [] = {
 	{ NULL, '\0', POPT_ARG_CALLBACK, parse_an_arg, 0, NULL, NULL },
 	{ "events", 'e', POPT_ARG_NONE, NULL, 'e', N_("Show events and quit"),
 	  NULL },
+	{ "todo",   0,   POPT_ARG_NONE, NULL, TODO_KEY, N_("Show TO-DO items and quit"),
+	  NULL },
 	{ "from", 'f', POPT_ARG_STRING, NULL, 'f', N_("Specifies start date [for --events]"), N_("DATE") },
 	{ "file", 'F', POPT_ARG_STRING, NULL, 'F', N_("File to load calendar from"), N_("FILE") },
 	{ "userfile", '\0', POPT_ARG_NONE, NULL, USERFILE_KEY, N_("Load the user calendar"), NULL },
@@ -785,7 +846,9 @@ main(int argc, char *argv[])
 
 	if (show_events)
 		dump_events ();
-
+	if (show_todo)
+		dump_todo ();
+	
 	client = gnome_master_client ();
 	if (client){
 		gtk_signal_connect (GTK_OBJECT (client), "save_yourself",
