@@ -126,8 +126,9 @@ card_new(void)
 	c->key.data = NULL;
 	
 	c->fname = c->mailer  = c->title = c->role  = c->comment = 
-	c->url   = c->uid     = empty_CardStrProperty();
+	c->categories = c->url = c->uid     = empty_CardStrProperty();
 	
+	c->categories.prop.encod = ENC_QUOTED_PRINTABLE;
 	c->comment.prop.encod = ENC_QUOTED_PRINTABLE;
 	
 	c->name.prop   = c->photo.prop = c->bday.prop    = c->timezn.prop   = 
@@ -155,6 +156,7 @@ card_new(void)
 	c->role.prop.type = PROP_ROLE;
 	c->logo.prop.type = PROP_LOGO;
 	c->org.prop.type = PROP_ORG;
+	c->categories.prop.type = PROP_CATEGORIES;
 	c->comment.prop.type = PROP_COMMENT;
 	c->rev.prop.type = PROP_REV;
 	c->sound.prop.type = PROP_SOUND;
@@ -192,6 +194,7 @@ card_free(Card *crd)
 	MY_FREE(crd->mailer.str); card_prop_free(crd->mailer.prop);
 	MY_FREE(crd->title.str); card_prop_free(crd->title.prop);
 	MY_FREE(crd->role.str); card_prop_free(crd->role.prop);
+	MY_FREE(crd->categories.str); card_prop_free(crd->categories.prop);
 	MY_FREE(crd->comment.str); card_prop_free(crd->comment.prop);
 	MY_FREE(crd->url.str); card_prop_free(crd->url.prop);
 	MY_FREE(crd->uid.str); card_prop_free(crd->uid.prop);
@@ -982,6 +985,12 @@ card_create_from_vobject (VObject *vcrd)
 			prop = &crd->org.prop;
 			crd->org = get_CardOrg(o);
 			break;
+		 case PROP_CATEGORIES:
+			prop = &crd->categories.prop;
+			crd->categories.str = g_strdup(str_val(o));
+			crd->categories.prop.encod = ENC_QUOTED_PRINTABLE;
+			free(the_str);
+			break;
 		 case PROP_COMMENT:
 			prop = &crd->comment.prop;
 			crd->comment.str = g_strdup(str_val(o));
@@ -1389,6 +1398,7 @@ card_convert_to_vobject(Card *crd)
 		add_strProp(vprop, VCOrgUnit4Prop, crd->org.unit4);
 		add_CardProperty(vprop, &crd->org.prop);
 	}
+        add_CardStrProperty(vobj, VCCategoriesProp, &crd->categories);
         add_CardStrProperty(vobj, VCCommentProp, &crd->comment);
 	if (crd->sound.prop.used) {
 		if (crd->sound.type != SOUND_PHONETIC)
