@@ -170,10 +170,12 @@ static void gnomecard_prop_apply(GtkWidget *widget, int page)
         crd->org.unit3 = MY_STRDUP("");
         crd->org.unit4 = MY_STRDUP("");
 #endif	
+	MY_FREE(crd->categories.str);
 	MY_FREE(crd->comment.str);
 	MY_FREE(crd->url.str);
 	MY_FREE(crd->email.address);
 	
+	crd->categories.str = MY_STRDUP(gtk_entry_get_text(GTK_ENTRY(ce->categories)));
 	crd->comment.str = gtk_editable_get_chars(GTK_EDITABLE(ce->comment), 
 			 0, gtk_text_get_length(GTK_TEXT(ce->comment)));
 	crd->url.str     = MY_STRDUP(gtk_entry_get_text(GTK_ENTRY(ce->url)));
@@ -564,6 +566,14 @@ extern void gnomecard_edit(GList *node)
 	vbox = my_gtk_vbox_new();
 	label = gtk_label_new(_("Explanatory"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(box->notebook), vbox, label);
+
+	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
+	label = gtk_label_new(_("Categories:"));
+	ce->categories = entry = my_gtk_entry_new(0, crd->categories.str);
+	my_connect(entry, "changed", box, &crd->categories.prop, PROP_CATEGORIES);
+	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	
 	label = gtk_label_new(_("Comment:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
@@ -701,6 +711,7 @@ gnomecard_setup_apply(GtkWidget *widget, int page)
 	snprintf(path, sizeof(path), "/GnomeCard/CardDisplay/Column%0d", i);
 	gnome_config_set_string(path, getColumnTypeNameFromType(hdrs[i]));
     }
+    gnome_config_sync();
 }
 
 
@@ -1506,6 +1517,7 @@ static void gnomecard_open_call(GtkWidget *widget, gpointer data)
 		gnomecard_fname = g_strdup(fname);
 		gtk_widget_destroy(widget);
 		gnome_config_set_string("/GnomeCard/file/open",  gnomecard_fname);
+		gnome_config_sync();
 	}
 }
 
@@ -1530,6 +1542,7 @@ extern void gnomecard_open_default (GtkWidget *widget, gpointer data)
 		g_free(gnomecard_fname);
 		gnomecard_fname = g_strdup("");
 		gnome_config_set_string("/GnomeCard/file/open",  gnomecard_fname);
+		gnome_config_sync();
 	}
 }
 
@@ -1601,7 +1614,7 @@ static void gnomecard_find_card(GtkWidget *w, gpointer data)
 	GnomeCardFind *p;
 	GList *l, *k;
 	Card *crd;
-	char *pattern, *crd_text[15];
+	char *pattern, *crd_text[16];
 	int i, wrapped, found, sens, back;
 	
 	p = (GnomeCardFind *) data;
@@ -1644,15 +1657,16 @@ static void gnomecard_find_card(GtkWidget *w, gpointer data)
 		crd_text[5] = crd->name.suffix;
 		crd_text[6] = crd->title.str;
 		crd_text[7] = crd->role.str;
-		crd_text[8] = crd->comment.str;
-		crd_text[9] = crd->url.str;
-		crd_text[10] = crd->org.name;
-		crd_text[11] = crd->org.unit1;
-		crd_text[12] = crd->org.unit2;
-		crd_text[13] = crd->org.unit3;
-		crd_text[14] = crd->org.unit4;
+		crd_text[8] = crd->categories.str;
+		crd_text[9] = crd->comment.str;
+		crd_text[10] = crd->url.str;
+		crd_text[11] = crd->org.name;
+		crd_text[12] = crd->org.unit1;
+		crd_text[13] = crd->org.unit2;
+		crd_text[14] = crd->org.unit3;
+		crd_text[15] = crd->org.unit4;
 		
-		for (i = 0; i < 15 && !found; i++)
+		for (i = 0; i < sizeof(crd_text)/sizeof(crd_text[0]) && !found; i++)
 		    if (gnomecard_match_pattern(pattern, crd_text[i], sens))
 			found = 1;
 		
@@ -1747,6 +1761,7 @@ static void gnomecard_find_card(GtkWidget *w, gpointer data)
 	gnome_config_set_bool("/GnomeCard/find/sens",  gnomecard_find_sens);
 	gnome_config_set_bool("/GnomeCard/find/back",  gnomecard_find_back);
 	gnome_config_set_string("/GnomeCard/find/str",  gnomecard_find_str);
+	gnome_config_sync();
 }
 
 extern void gnomecard_find_card_call(GtkWidget *widget, gpointer data)
