@@ -229,7 +229,7 @@ gnomecard_create_phone_page(Card *crd, GnomeCardEditor *ce,
     thebox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
     
     /* make a frame for the phone entry area */
-    frame = gtk_frame_new(_("Phone"));
+    frame = gtk_frame_new(_("Telephone Numbers"));
     gtk_box_pack_start(GTK_BOX(thebox), frame, TRUE, TRUE, 0);
     
     /* make a hbox for entire phone entry area */
